@@ -6,6 +6,7 @@ The source code for this program is not published or otherwise divested of its t
 irrespective of what has been deposited with the U.S. Copyright Office.
 Copyright (c) 2020 Red Hat, Inc.
 */
+// Copyright Contributors to the Open Cluster Management project
 
 package transforms
 
@@ -59,7 +60,8 @@ func PodResourceBuilder(p *v1.Pod) *PodResource {
 				reason = "Init:" + container.State.Terminated.Reason
 			}
 			initializing = true
-		case container.State.Waiting != nil && len(container.State.Waiting.Reason) > 0 && container.State.Waiting.Reason != "PodInitializing":
+		case container.State.Waiting != nil && len(container.State.Waiting.Reason) > 0 &&
+			container.State.Waiting.Reason != "PodInitializing":
 			reason = "Init:" + container.State.Waiting.Reason
 			initializing = true
 		default:
@@ -103,6 +105,7 @@ func PodResourceBuilder(p *v1.Pod) *PodResource {
 	}
 
 	node := transformCommon(p) // Start off with the common properties
+	ownerReferences := p.ObjectMeta.OwnerReferences
 
 	apiGroupVersion(p.TypeMeta, &node) // add kind, apigroup and version
 	// Extract the properties specific to this type
@@ -113,6 +116,10 @@ func PodResourceBuilder(p *v1.Pod) *PodResource {
 	node.Properties["container"] = containers
 	node.Properties["image"] = images
 	node.Properties["startedAt"] = ""
+	if len(ownerReferences) > 0 &&
+		(ownerReferences[0].Kind == "ReplicationController" || ownerReferences[0].Kind == "ReplicaSet") {
+		node.Properties["_ownerUID"] = ownerRefUID(ownerReferences)
+	}
 	if p.Status.StartTime != nil {
 		node.Properties["startedAt"] = p.Status.StartTime.UTC().Format(time.RFC3339)
 	}
@@ -138,7 +145,7 @@ func (p PodResource) BuildEdges(ns NodeStore) []Edge {
 		EdgeType:  "attachedTo",
 		Kind:      p.node.Properties["kind"].(string)}
 
-	//attachedTo edges
+	// attachedTo edges
 	secretMap := make(map[string]struct{})
 	configmapMap := make(map[string]struct{})
 	volumeClaimMap := make(map[string]struct{})
@@ -173,14 +180,14 @@ func (p PodResource) BuildEdges(ns NodeStore) []Edge {
 		}
 	}
 
-	//Create all 'attachedTo' edges between pod and nodes of a specific kind(secrets, configmaps, volumeClaims, volumes)
+	// Create all 'attachedTo' edges between pod and nodes of a specific kind(secrets, configmaps, volumeClaims, volumes)
 	ret = append(ret, edgesByDestinationName(secretMap, "Secret", nodeInfo, ns, []string{})...)
 	ret = append(ret, edgesByDestinationName(configmapMap, "ConfigMap", nodeInfo, ns, []string{})...)
 	ret = append(ret, edgesByDestinationName(volumeClaimMap, "PersistentVolumeClaim", nodeInfo, ns, []string{})...)
 	nodeInfo.NameSpace = "_NONE"
 	ret = append(ret, edgesByDestinationName(volumeMap, "PersistentVolume", nodeInfo, ns, []string{})...)
 
-	//runsOn edges
+	// runsOn edges
 	if p.Spec.NodeName != "" {
 		nodeName := p.Spec.NodeName
 		srcNode := ns.ByUID[UID]
