@@ -6,25 +6,24 @@ The source code for this program is not published or otherwise divested of its t
 irrespective of what has been deposited with the U.S. Copyright Office.
 Copyright (c) 2020 Red Hat, Inc.
 */
+// Copyright Contributors to the Open Cluster Management project
 
 package transforms
 
 import (
-	"fmt"
 	"runtime/debug"
 	"strings"
 	"sync"
 
 	"github.com/golang/glog"
-	acmapp "github.com/open-cluster-management/multicloud-operators-channel/pkg/apis/apps/v1"
-	appDeployable "github.com/open-cluster-management/multicloud-operators-deployable/pkg/apis/apps/v1"
-	rule "github.com/open-cluster-management/multicloud-operators-placementrule/pkg/apis/apps/v1"
-	appHelmRelease "github.com/open-cluster-management/multicloud-operators-subscription-release/pkg/apis/apps/v1"
-	subscription "github.com/open-cluster-management/multicloud-operators-subscription/pkg/apis/apps/v1"
+	appDeployable "github.com/stolostron/multicloud-operators-deployable/pkg/apis/apps/v1"
+	rule "github.com/stolostron/multicloud-operators-placementrule/pkg/apis/apps/v1"
+	acmapp "open-cluster-management.io/multicloud-operators-channel/pkg/apis/apps/v1"
+	appHelmRelease "open-cluster-management.io/multicloud-operators-subscription/pkg/apis/apps/helmrelease/v1"
+	subscription "open-cluster-management.io/multicloud-operators-subscription/pkg/apis/apps/v1"
 	application "sigs.k8s.io/application/api/v1beta1"
 
-	policy "github.com/open-cluster-management/governance-policy-propagator/pkg/apis/policies/v1"
-	mcm "github.com/open-cluster-management/multicloud-operators-foundation/pkg/apis/mcm/v1alpha1"
+	policy "github.com/stolostron/governance-policy-propagator/pkg/apis/policy/v1"
 
 	apps "k8s.io/api/apps/v1"
 
@@ -33,7 +32,6 @@ import (
 	core "k8s.io/api/core/v1"
 	"k8s.io/apimachinery/pkg/apis/meta/v1/unstructured"
 	"k8s.io/apimachinery/pkg/runtime"
-	"k8s.io/helm/pkg/proto/hapi/release"
 
 	ocpapp "github.com/openshift/api/apps/v1"
 )
@@ -41,6 +39,8 @@ import (
 // Operation is the event operation
 type Operation int
 
+var APPS_OPEN_CLUSTER_MANAGEMENT_IO = "apps.open-cluster-management.io"
+
 const (
 	Create Operation = iota // 0
 	Update                  // 1
@@ -52,10 +52,10 @@ type Event struct {
 	Time           int64
 	Operation      Operation
 	Resource       *unstructured.Unstructured
-	ResourceString string // This is a plural identifier of the kind, though in k8s this is called a "resource". e.g. for a pod, this is "pods"
+	ResourceString string // This is a plural identifier of the kind.
 }
 
-// A generic node type that is passed to the aggregator for translation to whatever graphDB technology.
+// A generic node type that is passed to the aggregator to store in the database.
 type Node struct {
 	UID            string                 `json:"uid"`
 	ResourceString string                 `json:"resourceString"`
@@ -74,7 +74,8 @@ func (n Node) GetMetadata(md string) string {
 	return ""
 }
 
-// These are the input to the sender. They have the node, and then they keep the time which is used for reconciling this version with other versions that the sender may already have.
+// These are the input to the sender. They have the node, and then they keep the time which is used for reconciling
+// this version with other versions that the sender may already have.
 type NodeEvent struct {
 	Node
 	ComputeEdges func(ns NodeStore) []Edge
@@ -86,38 +87,7 @@ type Deletion struct {
 	UID string `json:"uid,omitempty"`
 }
 
-// Builds a selfLink using data from the node. This is used as a workaround to stay compatible with
-// kubernetes 1.20 which deprecates this field.
-func buildSelfLink(nodeProps map[string]interface{}, resourceString string) string {
-	namespace := ""
-	if nodeProps["namespace"] != nil && nodeProps["namespace"].(string) != "" {
-		namespace = "/namespaces/" + nodeProps["namespace"].(string)
-	}
-
-	root := "api/v1"
-	groupVersion := ""
-	if nodeProps["apigroup"] != nil && nodeProps["apigroup"].(string) != "" &&
-		nodeProps["apiversion"] != nil && nodeProps["apiversion"].(string) != "" {
-		root = "apis"
-		groupVersion = "/" + nodeProps["apigroup"].(string) + "/" + nodeProps["apiversion"].(string)
-	} else if nodeProps["apigroup"] != nil && nodeProps["apigroup"].(string) != "" {
-		groupVersion = "/" + nodeProps["apigroup"].(string)
-	} else if nodeProps["apiversion"] != nil && nodeProps["apiversion"].(string) != "" {
-		groupVersion = "/" + nodeProps["apiversion"].(string)
-		root = "api"
-	}
-
-	// The selfLink format is: /api/apigroup/apiversion/namespaces/namespace/kind-plural/name
-	// - apigroup, version, and namespace are optional
-	// Example 1:  /api/v1/namespaces/kube-system/configmaps/cluster-config-v1
-	// Example 2:  /api/v1/nodes/ip-10-0-143-224.us-east-2.compute.internal
-	selfLink := fmt.Sprintf("/%s%s%s/%s/%s", root, groupVersion, namespace, resourceString, nodeProps["name"].(string))
-	selfLink = strings.ReplaceAll(selfLink, ":", "%3A")
-	return selfLink
-}
-
-// make new constructor here, dry up code, then start testing
-
+// make new constructor here.
 func NewNodeEvent(event *Event, trans Transform, resourceString string) NodeEvent {
 	ne := NodeEvent{
 		Time:         event.Time,
@@ -126,13 +96,6 @@ func NewNodeEvent(event *Event, trans Transform, resourceString string) NodeEven
 		ComputeEdges: trans.BuildEdges,
 	}
 	ne.ResourceString = resourceString
-
-	// Kubernetes 1.20 deprecates selfLink. This workaround builds a self link to satisfy the existing logic.
-	// A permanent fix is delivered in ACM 2.2
-	if ne.Node.Properties["selfLink"] == nil || ne.Node.Properties["selfLink"].(string) == "" {
-		ne.Node.Properties["selfLink"] = buildSelfLink(ne.Node.Properties, resourceString)
-	}
-
 	return ne
 }
 
@@ -166,7 +129,6 @@ type Transform interface {
 type Transformer struct {
 	Input  chan *Event    // Put your k8s resources and corresponding times in here.
 	Output chan NodeEvent // And receive your aggregator-ready nodes (and times) from here.
-	// TODO add stopper channel?
 }
 
 var (
@@ -193,13 +155,14 @@ func NewTransformer(inputChan chan *Event, outputChan chan NodeEvent, numRoutine
 
 }
 
-// This function is to be run as a goroutine that processes k8s objects into Nodes, then spits them out into the output channel.
-// If anything goes wrong in here that requires you to skip the current resource, call panic() and the routine will be spun back up by handleRoutineExit and the bad resource won't be in there because it was already taken out by the previous run.
+// This function processes k8s objects into Nodes, then pass them into the output channel.
+// If anything goes wrong in here that requires you to skip the current resource, call panic()
+// and the routine will be spun back up by handleRoutineExit and the bad resource won't be in there
+// because it was already taken out by the previous run.
 func TransformRoutine(input chan *Event, output chan NodeEvent) {
 	defer handleRoutineExit(input, output)
 	glog.Info("Starting transformer routine")
 
-	// TODO not exactly sure, but we may need a stopper channel here.
 	for {
 		var trans Transform
 
@@ -216,19 +179,30 @@ func TransformRoutine(input chan *Event, output chan NodeEvent) {
 			}
 		}
 		kindApigroup := [2]string{event.Resource.GetKind(), apiGroup}
-		//TODO: Might have to add more transform cases if resources like DaemonSet, StatefulSet etc. have other apigroups
+		// Might have to add more transform cases if resources like DaemonSet, StatefulSet etc. have other apigroups
 		switch kindApigroup {
 		case [2]string{"Application", "app.k8s.io"}:
 			typedResource := application.Application{}
-			err := runtime.DefaultUnstructuredConverter.FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
+			err := runtime.DefaultUnstructuredConverter.
+				FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
 			if err != nil {
 				panic(err) // Will be caught by handleRoutineExit
 			}
 			trans = ApplicationResourceBuilder(&typedResource)
 
-		case [2]string{"Channel", "app.ibm.com"}, [2]string{"Channel", "apps.open-cluster-management.io"}:
+		case [2]string{"Application", "argoproj.io"}:
+			typedResource := ArgoApplication{}
+			err := runtime.DefaultUnstructuredConverter.
+				FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
+			if err != nil {
+				panic(err) // Will be caught by handleRoutineExit
+			}
+			trans = ArgoApplicationResourceBuilder(&typedResource)
+
+		case [2]string{"Channel", APPS_OPEN_CLUSTER_MANAGEMENT_IO}:
 			typedResource := acmapp.Channel{}
-			err := runtime.DefaultUnstructuredConverter.FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
+			err := runtime.DefaultUnstructuredConverter.
+				FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
 			if err != nil {
 				panic(err) // Will be caught by handleRoutineExit
 			}
@@ -236,7 +210,8 @@ func TransformRoutine(input chan *Event, output chan NodeEvent) {
 
 		case [2]string{"CronJob", "batch"}:
 			typedResource := batchBeta.CronJob{}
-			err := runtime.DefaultUnstructuredConverter.FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
+			err := runtime.DefaultUnstructuredConverter.
+				FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
 			if err != nil {
 				panic(err) // Will be caught by handleRoutineExit
 			}
@@ -244,7 +219,8 @@ func TransformRoutine(input chan *Event, output chan NodeEvent) {
 
 		case [2]string{"DaemonSet", "extensions"}:
 			typedResource := apps.DaemonSet{}
-			err := runtime.DefaultUnstructuredConverter.FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
+			err := runtime.DefaultUnstructuredConverter.
+				FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
 			if err != nil {
 				panic(err) // Will be caught by handleRoutineExit
 			}
@@ -252,31 +228,26 @@ func TransformRoutine(input chan *Event, output chan NodeEvent) {
 
 		case [2]string{"DaemonSet", "apps"}:
 			typedResource := apps.DaemonSet{}
-			err := runtime.DefaultUnstructuredConverter.FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
+			err := runtime.DefaultUnstructuredConverter.
+				FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
 			if err != nil {
 				panic(err) // Will be caught by handleRoutineExit
 			}
 			trans = DaemonSetResourceBuilder(&typedResource)
 
-		case [2]string{"Deployable", "app.ibm.com"}, [2]string{"Deployable", "apps.open-cluster-management.io"}:
+		case [2]string{"Deployable", APPS_OPEN_CLUSTER_MANAGEMENT_IO}:
 			typedResource := appDeployable.Deployable{}
-			err := runtime.DefaultUnstructuredConverter.FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
+			err := runtime.DefaultUnstructuredConverter.
+				FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
 			if err != nil {
 				panic(err) // Will be caught by handleRoutineExit
 			}
 			trans = AppDeployableResourceBuilder(&typedResource)
 
-		case [2]string{"Deployable", "mcm.ibm.com"}:
-			typedResource := appDeployable.Deployable{}
-			err := runtime.DefaultUnstructuredConverter.FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
-			if err != nil {
-				panic(err) // Will be caught by handleRoutineExit
-			}
-			trans = DeployableResourceBuilder(&typedResource)
-
 		case [2]string{"Deployment", "apps"}:
 			typedResource := apps.Deployment{}
-			err := runtime.DefaultUnstructuredConverter.FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
+			err := runtime.DefaultUnstructuredConverter.
+				FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
 			if err != nil {
 				panic(err) // Will be caught by handleRoutineExit
 			}
@@ -284,7 +255,8 @@ func TransformRoutine(input chan *Event, output chan NodeEvent) {
 
 		case [2]string{"Deployment", "extensions"}:
 			typedResource := apps.Deployment{}
-			err := runtime.DefaultUnstructuredConverter.FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
+			err := runtime.DefaultUnstructuredConverter.
+				FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
 			if err != nil {
 				panic(err) // Will be caught by handleRoutineExit
 			}
@@ -293,16 +265,18 @@ func TransformRoutine(input chan *Event, output chan NodeEvent) {
 			//This is an ocp specific resource
 		case [2]string{"DeploymentConfig", "apps.openshift.io"}:
 			typedResource := ocpapp.DeploymentConfig{}
-			err := runtime.DefaultUnstructuredConverter.FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
+			err := runtime.DefaultUnstructuredConverter.
+				FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
 			if err != nil {
 				panic(err) // Will be caught by handleRoutineExit
 			}
 			trans = DeploymentConfigResourceBuilder(&typedResource)
 
 			//This is the application's HelmCR of kind HelmRelease.
-		case [2]string{"HelmRelease", "apps.open-cluster-management.io"}:
+		case [2]string{"HelmRelease", APPS_OPEN_CLUSTER_MANAGEMENT_IO}:
 			typedResource := appHelmRelease.HelmRelease{}
-			err := runtime.DefaultUnstructuredConverter.FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
+			err := runtime.DefaultUnstructuredConverter.
+				FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
 			if err != nil {
 				panic(err) // Will be caught by handleRoutineExit
 			}
@@ -310,7 +284,8 @@ func TransformRoutine(input chan *Event, output chan NodeEvent) {
 
 		case [2]string{"Job", "batch"}:
 			typedResource := batch.Job{}
-			err := runtime.DefaultUnstructuredConverter.FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
+			err := runtime.DefaultUnstructuredConverter.
+				FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
 			if err != nil {
 				panic(err) // Will be caught by handleRoutineExit
 			}
@@ -318,7 +293,8 @@ func TransformRoutine(input chan *Event, output chan NodeEvent) {
 
 		case [2]string{"Namespace", ""}:
 			typedResource := core.Namespace{}
-			err := runtime.DefaultUnstructuredConverter.FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
+			err := runtime.DefaultUnstructuredConverter.
+				FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
 			if err != nil {
 				panic(err) // Will be caught by handleRoutineExit
 			}
@@ -326,7 +302,8 @@ func TransformRoutine(input chan *Event, output chan NodeEvent) {
 
 		case [2]string{"Node", ""}:
 			typedResource := core.Node{}
-			err := runtime.DefaultUnstructuredConverter.FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
+			err := runtime.DefaultUnstructuredConverter.
+				FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
 			if err != nil {
 				panic(err) // Will be caught by handleRoutineExit
 			}
@@ -334,7 +311,8 @@ func TransformRoutine(input chan *Event, output chan NodeEvent) {
 
 		case [2]string{"PersistentVolume", ""}:
 			typedResource := core.PersistentVolume{}
-			err := runtime.DefaultUnstructuredConverter.FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
+			err := runtime.DefaultUnstructuredConverter.
+				FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
 			if err != nil {
 				panic(err) // Will be caught by handleRoutineExit
 			}
@@ -342,31 +320,26 @@ func TransformRoutine(input chan *Event, output chan NodeEvent) {
 
 		case [2]string{"PersistentVolumeClaim", ""}:
 			typedResource := core.PersistentVolumeClaim{}
-			err := runtime.DefaultUnstructuredConverter.FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
+			err := runtime.DefaultUnstructuredConverter.
+				FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
 			if err != nil {
 				panic(err) // Will be caught by handleRoutineExit
 			}
 			trans = PersistentVolumeClaimResourceBuilder(&typedResource)
 
-		case [2]string{"PlacementBinding", "mcm.ibm.com"}, [2]string{"PlacementBinding", "apps.open-cluster-management.io"}:
-			typedResource := mcm.PlacementBinding{}
-			err := runtime.DefaultUnstructuredConverter.FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
+		case [2]string{"PlacementBinding", APPS_OPEN_CLUSTER_MANAGEMENT_IO}:
+			typedResource := policy.PlacementBinding{}
+			err := runtime.DefaultUnstructuredConverter.
+				FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
 			if err != nil {
 				panic(err) // Will be caught by handleRoutineExit
 			}
 			trans = PlacementBindingResourceBuilder(&typedResource)
 
-		case [2]string{"PlacementPolicy", "mcm.ibm.com"}, [2]string{"PlacementPolicy", "apps.open-cluster-management.io"}:
-			typedResource := mcm.PlacementPolicy{}
-			err := runtime.DefaultUnstructuredConverter.FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
-			if err != nil {
-				panic(err) // Will be caught by handleRoutineExit
-			}
-			trans = PlacementPolicyResourceBuilder(&typedResource)
-
-		case [2]string{"PlacementRule", "app.ibm.com"}, [2]string{"PlacementRule", "apps.open-cluster-management.io"}:
+		case [2]string{"PlacementRule", APPS_OPEN_CLUSTER_MANAGEMENT_IO}:
 			typedResource := rule.PlacementRule{}
-			err := runtime.DefaultUnstructuredConverter.FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
+			err := runtime.DefaultUnstructuredConverter.
+				FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
 			if err != nil {
 				panic(err) // Will be caught by handleRoutineExit
 			}
@@ -374,15 +347,18 @@ func TransformRoutine(input chan *Event, output chan NodeEvent) {
 
 		case [2]string{"Pod", ""}:
 			typedResource := core.Pod{}
-			err := runtime.DefaultUnstructuredConverter.FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
+			err := runtime.DefaultUnstructuredConverter.
+				FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
 			if err != nil {
 				panic(err) // Will be caught by handleRoutineExit
 			}
 			trans = PodResourceBuilder(&typedResource)
 
-		case [2]string{"Policy", "policy.open-cluster-management.io"}, [2]string{"Policy", "policies.open-cluster-management.io"}:
+		case [2]string{"Policy", "policy.open-cluster-management.io"},
+			[2]string{"Policy", "policies.open-cluster-management.io"}:
 			typedResource := policy.Policy{}
-			err := runtime.DefaultUnstructuredConverter.FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
+			err := runtime.DefaultUnstructuredConverter.
+				FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
 			if err != nil {
 				panic(err) // Will be caught by handleRoutineExit
 			}
@@ -390,7 +366,8 @@ func TransformRoutine(input chan *Event, output chan NodeEvent) {
 
 		case [2]string{"ReplicaSet", "apps"}:
 			typedResource := apps.ReplicaSet{}
-			err := runtime.DefaultUnstructuredConverter.FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
+			err := runtime.DefaultUnstructuredConverter.
+				FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
 			if err != nil {
 				panic(err) // Will be caught by handleRoutineExit
 			}
@@ -398,7 +375,8 @@ func TransformRoutine(input chan *Event, output chan NodeEvent) {
 
 		case [2]string{"ReplicaSet", "extensions"}:
 			typedResource := apps.ReplicaSet{}
-			err := runtime.DefaultUnstructuredConverter.FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
+			err := runtime.DefaultUnstructuredConverter.
+				FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
 			if err != nil {
 				panic(err) // Will be caught by handleRoutineExit
 			}
@@ -406,7 +384,8 @@ func TransformRoutine(input chan *Event, output chan NodeEvent) {
 
 		case [2]string{"Service", ""}:
 			typedResource := core.Service{}
-			err := runtime.DefaultUnstructuredConverter.FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
+			err := runtime.DefaultUnstructuredConverter.
+				FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
 			if err != nil {
 				panic(err) // Will be caught by handleRoutineExit
 			}
@@ -414,73 +393,39 @@ func TransformRoutine(input chan *Event, output chan NodeEvent) {
 
 		case [2]string{"StatefulSet", "apps"}:
 			typedResource := apps.StatefulSet{}
-			err := runtime.DefaultUnstructuredConverter.FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
+			err := runtime.DefaultUnstructuredConverter.
+				FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
 			if err != nil {
 				panic(err) // Will be caught by handleRoutineExit
 			}
 			trans = StatefulSetResourceBuilder(&typedResource)
 
-		case [2]string{"Subscription", "app.ibm.com"}, [2]string{"Subscription", "apps.open-cluster-management.io"}:
+		case [2]string{"Subscription", APPS_OPEN_CLUSTER_MANAGEMENT_IO}:
 			typedResource := subscription.Subscription{}
-			err := runtime.DefaultUnstructuredConverter.FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
+			err := runtime.DefaultUnstructuredConverter.
+				FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
 			if err != nil {
 				panic(err) // Will be caught by handleRoutineExit
 			}
 			trans = SubscriptionResourceBuilder(&typedResource)
 
+		case [2]string{"PolicyReport", "wgpolicyk8s.io"}:
+			typedResource := PolicyReport{}
+			err := runtime.DefaultUnstructuredConverter.
+				FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
+			if err != nil {
+				panic(err) // Will be caught by handleRoutineExit
+			}
+			trans = PolicyReportResourceBuilder(&typedResource)
+
 		default:
 			trans = GenericResourceBuilder(event.Resource)
 		}
 
 		output <- NewNodeEvent(event, trans, event.ResourceString)
-
-		if IsHelmRelease(event.Resource) {
-			typedResource := core.ConfigMap{}
-			err := runtime.DefaultUnstructuredConverter.FromUnstructured(event.Resource.UnstructuredContent(), &typedResource)
-			if err != nil {
-				panic(err) // Will be caught by handleRoutineExit
-			}
-			releaseName := typedResource.GetLabels()["NAME"]
-			release := getReleaseFromHelm(releaseName)
-			if release == nil {
-				AddToRetryChannel(event)
-			}
-			releaseTrans := HelmReleaseResource{&typedResource, release}
-			output <- NewNodeEvent(event, releaseTrans, "releases")
-		}
 	}
 }
 
-//	If the resource is a ConfigMap with label "OWNER:TILLER", it references a Helm Release
-func IsHelmRelease(resource *unstructured.Unstructured) bool {
-	if kind := resource.GetKind(); kind == "ConfigMap" {
-		for label, value := range resource.GetLabels() {
-			if label == "OWNER" && value == "TILLER" {
-				return true
-			}
-		}
-	}
-	return false
-}
-
-func getReleaseFromHelm(releaseName string) *release.Release {
-	helmClient := GetHelmClient()
-	if !HealthyConnection() {
-		if len(helmReleaseRetry) < 1 {
-			glog.Warning("Helm client not healthy; Cannot fetch helm release:", releaseName)
-		}
-		return nil
-	}
-
-	rc, err := helmClient.ReleaseContent(releaseName)
-	if err != nil {
-		glog.Warning("Failed to fetch helm release: ", releaseName, err)
-		return nil
-	}
-	glog.V(3).Info("Retrieved helm release from Tiller: ", releaseName)
-	return rc.GetRelease()
-}
-
 // Handles a panic from inside transformRoutine.
 // If the panic was due to an error, starts another transformRoutine with the same channels as this one.
 // If not, just lets it die.
@@ -490,7 +435,8 @@ func handleRoutineExit(input chan *Event, output chan NodeEvent) {
 		glog.Errorf("Error in transformer routine: %v\n", r)
 		glog.Error(string(debug.Stack()))
 
-		// Start up a new routine with the same channels as the old one. The bad input will be gone since the old routine (the one that just crashed) took it out of the channel.
+		// Start up a new routine with the same channels as the old one. The bad input will be gone since the
+		// old routine (the one that just crashed) took it out of the channel.
 		go TransformRoutine(input, output)
 	}
 }
